starcluster.exception.PluginLoadError

Package starcluster :: Module exception :: Class PluginLoadError |
[hide private]
[frames] | no frames]

# Class PluginLoadError

source code

Raised when an error is encountered while loading a plugin

Instance Methods | [hide private]
Inherited from `BaseException`: `__init__`, `__str__`, `explain` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`